enableANS abstract method

Future<void> enableANS(
  1. bool enable
)

Enables or disables active noise suppression (ANS, aka ANC).

Available since: 1.0.0 Description: After turning on this function, the human voice can be made clearer. This function is better at suppressing continuous noise (such as the sound of rain and other white noise). Use case: This feature can be turned on when noise suppression is needed to improve the vocal quality and user experience of recorded audio. When to call: Called at any time after init. Caution: This API can only be called normally after the authentication is within the legal usage period, or the use is allowed in the authentication information; otherwise, an error message will be reported that the authentication has expired or this feature is not supported. Restrictions: None.

  • enable Whether to enable noise suppression, true: enable, false: disable

Implementation

Future<void> enableANS(bool enable);