setANSParam abstract method
Set noise suppression parameters, currently only includes noise suppression mode.
Available since: 1.0.0
Description: When noise suppression is turned on using enableANS, you can use this function to switch between different noise suppression modes to control the degree of noise suppression.
Use case: When the default noise suppression effect does not meet expectations, you can use this function to adjust the noise suppression mode.
Default value: When this function is not called, the default noise suppression mode is Medium.
When to call: Called at any time after init.
Caution: This API can only be called normally after the authentication is within the legal usage period, or the use is allowed in the authentication information; otherwise, an error message will be reported that the authentication has expired or this feature is not supported.
Restrictions: None.
paramANS parameters, including ANS mode
Implementation
Future<void> setANSParam(ZIMAudioANSParam param);